#!/usr/bin/env ruby
require("gsl")

f = GSL::Function.new { |x|
  pow(x, 1.5)
}

printf ("f(x) = x^(3/2)\n");

x = 2.0
result, abserr = f.diff_central(x)
printf("x = 2.0\n");
printf("f'(x) = %.10f +/- %.5f\n", result, abserr);
printf("exact = %.10f\n\n", 1.5 * Math::sqrt(2.0));

x = 0.0
result, abserr = f.diff_forward(x)
printf("x = 0.0\n");
printf("f'(x) = %.10f +/- %.5f\n", result, abserr);
printf("exact = %.10f\n", 0.0);

f2 = Function.new { |x, a| Math::exp(a*x) }

f2.set_params(2)
p f2.diff_central(0)

f2.set_params(3)
p f2.diff_central(0)

f2.set_params(123)
p f2.diff_central(0)

p Diff.central(f2, 0)
p Diff.forward(f2, 0)
p Diff.backward(f2, 0)
